# Usage

:::{warning}

`pycompwa` is no longer maintained. Use the
[ComPWA](https://compwa-org.rtfd.io) packages [QRules](https://qrules.rtfd.io),
[AmpForm](https://ampform.rtfd.io), and
[TensorWaves](https://tensorwaves.rtfd.io) instead!

:::

The examples in the following pages illustrate how to use the tools that
{mod}`pycompwa` offers. The examples were written as Jupyter notebooks and can
be downloaded [here](https://github.com/ComPWA/pycompwa/tree/main/docs/usage).

```{toctree}
:maxdepth: 2

usage/workflow.rst
usage/tools.rst
```
